@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2009  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2009, 2010  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -22,12 +22,6 @@
 
 #include "internal.h"
 
-/* Get i18n. */
-#include <gettext.h>
-#define _(String) dgettext (PACKAGE, String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
-
 /* _gss_find_mech */
 #include "meta.h"
 
@@ -194,7 +188,7 @@ gss_display_status (OM_uint32 * minor_status,
 {
   size_t i;
 
-  bindtextdomain (PACKAGE, LOCALEDIR);
+  bindtextdomain (PACKAGE PO_SUFFIX, LOCALEDIR);
 
   if (minor_status)
     *minor_status = 0;
