@@ -28,63 +28,59 @@
 # include "krb5/protos.h"
 #endif
 
-static _gss_mech_api_desc _gss_mech_apis[] =
-  {
+static _gss_mech_api_desc _gss_mech_apis[] = {
 #ifdef USE_KERBEROS5
-    {
-      &GSS_KRB5_static,
-      "GS2-KRB5",
-      "Kerberos V5",
-      N_("Kerberos V5 GSS-API mechanism"),
-      {
-	/* Mandatory name-types. */
-	&GSS_KRB5_NT_PRINCIPAL_NAME_static,
-	&GSS_C_NT_HOSTBASED_SERVICE_static,
-	&GSS_C_NT_EXPORT_NAME_static
-      },
-      gss_krb5_init_sec_context,
-      gss_krb5_canonicalize_name,
-      gss_krb5_export_name,
-      gss_krb5_wrap,
-      gss_krb5_unwrap,
-      gss_krb5_get_mic,
-      gss_krb5_verify_mic,
-      gss_krb5_display_status,
-      gss_krb5_acquire_cred,
-      gss_krb5_release_cred,
-      gss_krb5_accept_sec_context,
-      gss_krb5_delete_sec_context,
-      gss_krb5_context_time,
-      gss_krb5_inquire_cred,
-      gss_krb5_inquire_cred_by_mech},
+  {
+   &GSS_KRB5_static,
+   "GS2-KRB5",
+   "Kerberos V5",
+   N_("Kerberos V5 GSS-API mechanism"),
+   {
+    /* Mandatory name-types. */
+    &GSS_KRB5_NT_PRINCIPAL_NAME_static,
+    &GSS_C_NT_HOSTBASED_SERVICE_static,
+    &GSS_C_NT_EXPORT_NAME_static},
+   gss_krb5_init_sec_context,
+   gss_krb5_canonicalize_name,
+   gss_krb5_export_name,
+   gss_krb5_wrap,
+   gss_krb5_unwrap,
+   gss_krb5_get_mic,
+   gss_krb5_verify_mic,
+   gss_krb5_display_status,
+   gss_krb5_acquire_cred,
+   gss_krb5_release_cred,
+   gss_krb5_accept_sec_context,
+   gss_krb5_delete_sec_context,
+   gss_krb5_context_time,
+   gss_krb5_inquire_cred,
+   gss_krb5_inquire_cred_by_mech},
 #endif
-    {
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      {
-	NULL,
-	NULL,
-	NULL
-      },
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      NULL
-    }
-  };
+  {
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   {
+    NULL,
+    NULL,
+    NULL},
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL}
+};
 
 _gss_mech_api_t
 _gss_find_mech_no_default (const gss_OID oid)
@@ -117,8 +113,7 @@ _gss_find_mech_by_saslname (const gss_buffer_t sasl_mech_name)
   size_t i;
 
   if (sasl_mech_name == NULL
-      || sasl_mech_name->value == NULL
-      || sasl_mech_name->length == 0)
+      || sasl_mech_name->value == NULL || sasl_mech_name->length == 0)
     return NULL;
 
   for (i = 0; _gss_mech_apis[i].mech; i++)
