@@ -62,6 +62,51 @@ gss_create_empty_oid_set (OM_uint32 * minor_status, gss_OID_set * oid_set)
   return GSS_S_COMPLETE;
 }
 
+/*
+ * gss_copy_oid:
+ * @minor_status: (integer, modify) Mechanism specific status code.
+ * @src_oid: (Object ID, read) The object identifier to copy.
+ * @dest_oid: (Object ID, modify) The resultant copy of @src_oid.
+ *   Storage associated with this name must be freed by the
+ *   application, but gss_release_oid() cannot be used generally as it
+ *   deallocate the oid structure itself too.
+ *
+ * Make an exact copy of the given OID, that shares no memory areas
+ * with the original.
+ *
+ * WARNING: This function is a GNU GSS specific extension, and is not
+ * part of the official GSS API.
+ *
+ * Return value:
+ *
+ * `GSS_S_COMPLETE`: Successful completion.
+ **/
+static OM_uint32
+_gss_copy_oid (OM_uint32 * minor_status,
+	       const gss_OID src_oid, gss_OID dest_oid)
+{
+  if (minor_status)
+    *minor_status = 0;
+
+  if (!src_oid)
+    return GSS_S_FAILURE | GSS_S_CALL_INACCESSIBLE_READ;
+
+  if (src_oid->length == 0 || src_oid->elements == NULL)
+    return GSS_S_FAILURE | GSS_S_CALL_BAD_STRUCTURE;
+
+  dest_oid->length = src_oid->length;
+  dest_oid->elements = malloc (src_oid->length);
+  if (!dest_oid->elements)
+    {
+      if (minor_status)
+	*minor_status = ENOMEM;
+      return GSS_S_FAILURE;
+    }
+  memcpy (dest_oid->elements, src_oid->elements, src_oid->length);
+
+  return GSS_S_COMPLETE;
+}
+
 /**
  * gss_add_oid_set_member:
  * @minor_status: (integer, modify) Mechanism specific status code.
@@ -136,8 +181,8 @@ gss_add_oid_set_member (OM_uint32 * minor_status,
     (*oid_set)->elements = tmp;
   }
 
-  major_stat = gss_copy_oid (minor_status, member_oid,
-			     (*oid_set)->elements + ((*oid_set)->count - 1));
+  major_stat = _gss_copy_oid (minor_status, member_oid,
+			      (*oid_set)->elements + ((*oid_set)->count - 1));
   if (GSS_ERROR (major_stat))
     return major_stat;
 
